==> emiclock-1.0.4.tar.gz: emiclock-1.0.4/version.c <==
/*
 *  Emi Clock $B!=(B $B%P!<%8%g%s!?%Q%C%A%l%Y%k!?%j%j!<%9$N4IM}(B
 */

/*
 *  Copyright (c) 1994, 1995, 1997 Masayuki Koba.
 *
 *  $BK\%=%U%H%&%'%"$N%=!<%9$d%P%$%J%j$r:FG[I[$9$k>l9g$O!"<!$N>r7o$r=e<i$7$F(B
 *  $B2<$5$$!#(B
 *
 *  1. $BK\%=%U%H%&%'%"$rF~<j$7$?J}$K$O!"(BX11$BHG(B Emi Clock $B$N;HMQ8"$H!"Bh;0<T(B
 *     $B$X$N:FG[I[8"$,G'$a$i$l$^$9!#$?$@$7!":FG[I[$K4X$7$F$O!"F~<j;~$N%*%j(B
 *     $B%8%J%k$N$^$^2~JQ$;$:$K9T$&$3$H$,>r7o$G$9!#(B
 *  2. $BK\%=%U%H%&%'%"$N0lIt$^$?$OA4It$rCx:n8"<T$KL5CG$G2~JQ$7$FG[I[$9$k$3(B
 *     $B$H$O$G$-$^$;$s!#(B
 *  3. $BK\%=%U%H%&%'%"$N0lIt$^$?$OA4It$rCx:n8"<T$KL5CG$GFs<!MxMQ$9$k$3$H$O(B
 *     $B$G$-$^$;$s!#(B
 *  4. $BK\%=%U%H%&%'%"$r%7%9%F%`$K%P%s%I%k$7$?$j!"%7%9%F%`$NDI2C%Q%C%1!<%8(B
 *     $B$H$7$FBh;0<T$K:FG[I[$7$?$j$9$k>l9g$O!";vA0$KCx:n8"<T$K5v2D$,I,MW$G(B
 *     $B$9!#(B
 *  5. $BK\%=%U%H%&%'%"$r>&MQ$K;HMQ$9$k>l9g(B($B6bA,E*Mx1W$rF@$k>l9g(B)$B$O!";vA0$K(B
 *     $BCx:n8"<T$K5v2D$,I,MW$G$9!#$3$N>l9g!"4pK\E*$KM-=~$H$J$j$^$9!#(B
 *  6. $BK\%=%U%H%&%'%"$rMxMQ$9$k$3$H$K$h$C$FH/@8$7$?$$$+$J$kB;32$b!"Cx:n8"(B
 *     $B<T$OIi$o$J$$$b$N$H$7$^$9!#$3$l$K9g0U$G$-$J$$>l9g$O!";HMQ8"$,$J$$$b(B
 *     $B$N$H$7$^$9!#(B
 *  7. $B!H(BEmi Clock$B!I$N>&I8$*$h$SK\%=%U%H%&%'%"$N2hA|$d%G%6%$%s$K4X$9$kCx:n(B
 *     $B8"$O!"(BMotosoft $B$3$H!HK\(B $B=SLi!I;a$,M-$7$^$9!#(B
 *  8. $B!H(BEmi Clock$B!I$N>&I8$*$h$S2hA|$d%G%6%$%s$O!"(BX11$BHG(B Emi Clock $B3+H/$N$?(B
 *     $B$a!"(BMotosoft $B$h$j!H8E>l(B $B@59T!I$X8D?ME*$K%i%$%;%s%96!M?$5$l$F$^$9!#(B
 *     $BBh;0<T$XFs<!%i%$%;%s%96!M?$9$k$3$H$OG'$a$i$l$F$*$j$^$;$s!#(B
 *  9. Motosoft $B$H8E>l$KL5CG$G!"K\%=%U%H%&%'%"$N2hA|%G!<%?$rFs<!MxMQ$9$k$3(B
 *     $B$H$r6X;_$7$^$9!#(B
 * 10. $B$3$3$K5-=R$7$?0J30$N8"Mx$K$D$$$F$O!"F|K\9q$NCx:n8"K!$K$h$k$b$N$H$7(B
 *     $B$^$9!#(B
 */


/* $B#C8@8l%i%$%V%i%j(B */
#include <stdio.h>		/* $BI8=`F~=PNO%i%$%V%i%j(B */
#include <string.h>		/* $BJ8;zNsA`:n%i%$%V%i%j(B */

/* Emi Clock $BFH<+$N%X%C%@!<(B */
#include "include/version.h"	/* $B%P!<%8%g%s!?%Q%C%A%l%Y%k!?%j%j!<%9Dj5A(B */
#include "include/const.h"	/* $BDj?tDj5A(B */
#include "include/util.h"	/* $B%^%/%mDj5A(B */

/* RCS ID */
rcsId(versionId, "$Id: version.c,v 1.2 1997/01/11 02:35:53 masa-k Exp $")


/*
 *  $B%P!<%8%g%s>pJs$N<hF@(B
 */
char *
GetVersion()
{
    static char version[VERSION_STR_LEN];

    if (strcmp(RELEASE, FIX_STR) == 0) {
#if defined(__DATE__) && defined(__TIME__)
	sprintf(version, "%d.%d.%d (%s %s)",
			VERSION, MINOR_VERSION, PATCHLEVEL,
							__DATE__, __TIME__);
#else
	sprintf(version, "%d.%d.%d", VERSION, MINOR_VERSION, PATCHLEVEL);
#endif
    } else {
#if defined(__DATE__) && defined(__TIME__)
	sprintf(version, "%d.%d.%d (%s), %s %s",
			 VERSION, MINOR_VERSION, PATCHLEVEL, RELEASE,
							__DATE__, __TIME__);
#else
	sprintf(version, "%d.%d.%d (%s)",
			 VERSION, MINOR_VERSION, PATCHLEVEL, RELEASE);
#endif
    }

    return(version);
}

==> emiclock-2.0.2.tar.gz: emiclock-2.0.2/version.c <==
/*
 *  Emi Clock $B!=(B $B%P!<%8%g%s!?%Q%C%A%l%Y%k!?%j%j!<%9$N4IM}(B
 */

/*
 *  Copyright (c) 1994, 1995, 1997, 1999 Masayuki Koba
 *
 *  $BK\%=%U%H%&%'%"$N%=!<%9$d%P%$%J%j$r:FG[I[$9$k>l9g$O!"<!$N>r7o$r=e<i$7$F(B
 *  $B2<$5$$!#(B
 *
 *  1. $BK\%=%U%H%&%'%"$rF~<j$7$?J}$K$O!"(BX11$BHG(B Emi Clock $B$N;HMQ8"$H!"Bh;0<T(B
 *     $B$X$N:FG[I[8"$,G'$a$i$l$^$9!#$?$@$7!":FG[I[$K4X$7$F$O!"F~<j;~$N%*%j(B
 *     $B%8%J%k$N$^$^2~JQ$;$:$K9T$&$3$H$,>r7o$G$9!#(B
 *  2. $BK\%=%U%H%&%'%"$N0lIt$^$?$OA4It$rCx:n8"<T$KL5CG$G2~JQ$7$FG[I[$9$k$3(B
 *     $B$H$O$G$-$^$;$s!#(B
 *  3. $BK\%=%U%H%&%'%"$N0lIt$^$?$OA4It$rCx:n8"<T$KL5CG$GFs<!MxMQ$9$k$3$H$O(B
 *     $B$G$-$^$;$s!#(B
 *  4. $BK\%=%U%H%&%'%"$r%7%9%F%`$K%P%s%I%k$7$?$j!"%7%9%F%`$NDI2C%Q%C%1!<%8(B
 *     $B$H$7$FBh;0<T$K:FG[I[$7$?$j$9$k>l9g$O!";vA0$KCx:n8"<T$K5v2D$,I,MW$G(B
 *     $B$9!#(B
 *  5. $BK\%=%U%H%&%'%"$r>&MQ$K;HMQ$9$k>l9g(B($B6bA,E*Mx1W$rF@$k>l9g(B)$B$O!";vA0$K(B
 *     $BCx:n8"<T$K5v2D$,I,MW$G$9!#$3$N>l9g!"4pK\E*$KM-=~$H$J$j$^$9!#(B
 *  6. $BK\%=%U%H%&%'%"$rMxMQ$9$k$3$H$K$h$C$FH/@8$7$?$$$+$J$kB;32$b!"Cx:n8"(B
 *     $B<T$OIi$o$J$$$b$N$H$7$^$9!#$3$l$K9g0U$G$-$J$$>l9g$O!";HMQ8"$,$J$$$b(B
 *     $B$N$H$7$^$9!#(B
 *  7. $B!H(BEmi Clock$B!I$N>&I8$*$h$SK\%=%U%H%&%'%"$N2hA|$d%G%6%$%s$K4X$9$kCx:n(B
 *     $B8"$O!"(BMotosoft $B$3$H!HK\(B $B=SLi!I;a$,M-$7$^$9!#(B
 *  8. $B!H(BEmi Clock$B!I$N>&I8$*$h$S2hA|$d%G%6%$%s$O!"(BX11$BHG(B Emi Clock $B3+H/$N$?(B
 *     $B$a!"(BMotosoft $B$h$j!H8E>l(B $B@59T!I$X8D?ME*$K%i%$%;%s%96!M?$5$l$F$^$9!#(B
 *     $BBh;0<T$XFs<!%i%$%;%s%96!M?$9$k$3$H$OG'$a$i$l$F$*$j$^$;$s!#(B
 *  9. Motosoft $B$H8E>l$KL5CG$G!"K\%=%U%H%&%'%"$N2hA|%G!<%?$rFs<!MxMQ$9$k$3(B
 *     $B$H$r6X;_$7$^$9!#(B
 * 10. $B$3$3$K5-=R$7$?0J30$N8"Mx$K$D$$$F$O!"F|K\9q$NCx:n8"K!$K$h$k$b$N$H$7(B
 *     $B$^$9!#(B
 */


/* $B#C8@8l%i%$%V%i%j(B */
#include <stdio.h>		/* $BI8=`F~=PNO%i%$%V%i%j(B */
#include <string.h>		/* $BJ8;zNsA`:n%i%$%V%i%j(B */

/* Emi Clock $BFH<+$N%X%C%@!<(B */
#include "include/version.h"	/* $B%P!<%8%g%s!?%Q%C%A%l%Y%k!?%j%j!<%9Dj5A(B */
#include "include/const.h"	/* $BDj?tDj5A(B */
#include "include/util.h"	/* $B%^%/%mDj5A(B */

/* RCS ID */
rcsId(versionId, "$Id: version.c,v 1.3 1999/09/26 16:18:18 koba Exp $")


/*
 *  $B%P!<%8%g%s>pJs$N<hF@(B
 */
char *
GetVersion()
{
    static char version[VERSION_STR_LEN];

#if defined(__DATE__) && defined(__TIME__)
    sprintf(version, "%d.%d.%d (%s), BUILD: %s %s",
		     VERSION, MINOR_VERSION, PATCHLEVEL, RELEASE,
						    __DATE__, __TIME__);
#else
    sprintf(version, "%d.%d.%d (%s)",
		     VERSION, MINOR_VERSION, PATCHLEVEL, RELEASE);
#endif

    return(version);
}
